@@ -65,6 +65,8 @@ StatPlsmo <- ggplot2::ggproto("StatPlsmo", ggplot2::Stat,
   required_aes = c("x", "y"),
 
   setup_data = function(data, params) {
+    if (!requireNamespace("plyr", quietly = TRUE))
+      stop("This function requires the 'plyr' package.")
     rows <- plyr::daply(data, "group", function(df) length(unique(df$x)))
 
     if (all(rows == 1) && length(rows) > 1) {
